@@ -126,7 +126,7 @@ class DatabaseWrapper(BaseDatabaseWrapper):
         'SmallIntegerField': 'smallint',
         'TextField': 'nvarchar(max)',
         'TimeField': 'time',
-        'UUIDField': 'uniqueidentifier',
+        'UUIDField': 'char(32)',
     }
     data_types_suffix = {
         'AutoField': 'IDENTITY (1, 1)',
@@ -432,9 +432,6 @@ class DatabaseWrapper(BaseDatabaseWrapper):
         if (options.get('return_rows_bulk_insert', False)):
             self.features_class.can_return_rows_from_bulk_insert = True
 
-        if (options.get('has_native_uuid_field', True)):
-            Database.native_uuid = True
-            
         val = self.get_system_datetime
         if isinstance(val, str):
             raise ImproperlyConfigured(
@@ -621,11 +618,14 @@ class CursorWrapper(object):
         return sql
 
     def format_group_by_params(self, query, params):
+        # Prepare query for string formatting
+        query = re.sub(r'%\w+', '{}', query)
+
         if params:
             # Insert None params directly into the query
             if None in params:
-                null_params = ['NULL' if param is None else '%s' for param in params]
-                query = query % tuple(null_params)
+                null_params = ['NULL' if param is None else '{}' for param in params]
+                query = query.format(*null_params)
                 params = tuple(p for p in params if p is not None)
             params = [(param, type(param)) for param in params]
             params_dict = {param: '@var%d' % i for i, param in enumerate(set(params))}
@@ -637,8 +637,7 @@ class CursorWrapper(object):
                 datatype = self._as_sql_type(key[1], key[0])
                 variables.append("%s %s = %%s " % (value, datatype))
                 params.append(key[0])
-            query = ('DECLARE %s \n' % ','.join(variables)) + (query % tuple(args))
-
+            query = ('DECLARE %s \n' % ','.join(variables)) + (query.format(*args))
         return query, params
 
     def format_params(self, params):
